==> nomachine-8.13.1-1-x86_64.pkg.tar.zst: NX/lib/perl/nxnode/NXAuth.pm <==
############################################################################
#                                                                          #
#  Copyright (c) 2001, 2024 NoMachine, http://www.nomachine.com.           #
#                                                                          #
#  NXNODE, NX protocol compression and NX extensions to this software      #
#  are copyright of NoMachine. Redistribution and use of the present       #
#  software is allowed according to terms specified in the file LICENSE    #
#  which comes in the source distribution.                                 #
#                                                                          #
#  Check http://www.nomachine.com/licensing.html for applicability.        #
#                                                                          #
#  NX and NoMachine are trademarks of NoMachine S.a.r.l.                   #
#                                                                          #
#  All rights reserved.                                                    #
#                                                                          #
############################################################################
sub NXAuth::BEGIN{package NXAuth;no warnings;require strict;do{
"\x73\x74\x72\x69\x63\x74"->unimport ("\x72\x65\x66\x73")};}sub NXAuth::BEGIN{
package NXAuth;no warnings;require strict;do{"\x73\x74\x72\x69\x63\x74"->
unimport ("\x73\x75\x62\x73")};}sub NXAuth::BEGIN{package NXAuth;no warnings;
require Exporter;do{"\x45\x78\x70\x6f\x72\x74\x65\x72"->import};}sub 
NXAuth::BEGIN{package NXAuth;no warnings;require Common::NXBegin;do{
"\x43\x6f\x6d\x6d\x6f\x6e\x3a\x3a\x4e\x58\x42\x65\x67\x69\x6e"->import};}package
 NXAuth;no warnings;require Common::NXFile;(our (@ISA)=
"\x45\x78\x70\x6f\x72\x74\x65\x72");(our (@EXPORT)=(
"\x6e\x78\x61\x75\x74\x68\x41\x64\x64\x43\x6f\x6f\x6b\x69\x65",
"\x6e\x78\x61\x75\x74\x68\x52\x65\x6d\x6f\x76\x65\x43\x6f\x6f\x6b\x69\x65",
"\x6e\x78\x61\x75\x74\x68\x4c\x69\x73\x74\x43\x6f\x6f\x6b\x69\x65",
"\x6e\x78\x61\x75\x74\x68\x4c\x6f\x67\x43\x6f\x6f\x6b\x69\x65\x46\x72\x6f\x6d\x46\x69\x6c\x65"
));sub nxauthAddCookie{return (addCookie (@_));}sub nxauthLogCookieFromFile{(my $file
=shift (@_));my ($entries);(my (@command)=(
"\x2f\x75\x73\x72\x2f\x62\x69\x6e\x2f\x78\x61\x75\x74\x68","\x2d\x66",$file,
"\x6c\x69\x73\x74"));(my ($cmd_err,$cmd_out,$exit_value)=main::run_command ((
\@command),("")));}sub nxauthRemoveCookie{return (removeCookie (@_));}sub 
removeFromScript{(my $xauthorityFile=shift (@_));(my $script=shift (@_));if (((
not (defined ($xauthorityFile)))or ($xauthorityFile eq ("")))){Logger::warning (
"\x4d\x69\x73\x73\x69\x6e\x67\x20\x58\x61\x75\x74\x68\x6f\x72\x69\x74\x79\x20\x66\x69\x6c\x65"
);return ((0x15b8+ 434-0x1769));}Logger::debug ((
"\x47\x6f\x69\x6e\x67\x20\x74\x6f\x20\x6f\x70\x65\x6e\x20\x73\x63\x72\x69\x70\x74\x3a\x20"
.$script));(my $scriptFD=main::nxopen ($script,$NXBits::O_RDONLY,
(0x1d26+ 1094-0x216c)));if ((not (defined ($scriptFD)))){(my $errorNumber=
libnxh::NXGetError ());(my $errorstring=libnxh::NXGetErrorString ());
Logger::warning (((
"\x43\x61\x6e\x6e\x6f\x74\x20\x6f\x70\x65\x6e\x20\x73\x63\x72\x69\x70\x74\x3a\x20"
.$script)."\x2e"));Logger::warning (((((
"\x45\x72\x72\x6f\x72\x20\x69\x73\x3a\x20".$errorNumber)."\x2c\x20").
$errorstring)."\x2e"));return ((0x2084+ 813-0x23b0));}while (main::nxreadLine (
$scriptFD,(\$_))){if ( /remove\s(\S*:\d{1,5})$/ ){(my $dpyname=$1);if ((not (
removeCookie ($xauthorityFile,$dpyname)))){(my $errorNumber=libnxh::NXGetError 
());(my $errorstring=libnxh::NXGetErrorString ());Logger::warning (((((
"\x43\x61\x6e\x6e\x6f\x74\x20\x72\x65\x6d\x6f\x76\x65\x20\x63\x6f\x6f\x6b\x69\x65\x20\x66\x6f\x72\x20"
.$dpyname)."\x20\x66\x72\x6f\x6d\x20").$xauthorityFile)."\x2e"));Logger::warning
 ((((("\x45\x72\x72\x6f\x72\x20\x69\x73\x3a\x20".$errorNumber)."\x2c\x20").
$errorstring)."\x2e"));}}}main::nxclose ($scriptFD);return (
(0x05bf+ 5335-0x1a96));}sub nxauthListCookie{return (listCookie (@_));}sub 
addCookie{(my $inputfilename=shift (@_));(my $dpyname=shift (@_));(my $protoname
=shift (@_));(my $hexkey=shift (@_));if (((not (defined ($inputfilename)))or (
$inputfilename eq ("")))){Logger::warning (
"\x43\x61\x6e\x6e\x6f\x74\x20\x61\x64\x64\x20\x63\x6f\x6f\x6b\x69\x65\x2c\x20\x6d\x69\x73\x73\x69\x6e\x67\x20\x69\x6e\x70\x75\x74\x20\x66\x69\x6c\x65\x20\x6e\x61\x6d\x65\x2e"
);return ((0x0218+ 5216-0x1677));}if (((not (defined ($dpyname)))or ($dpyname eq
 ("")))){Logger::warning (
"\x43\x61\x6e\x6e\x6f\x74\x20\x61\x64\x64\x20\x63\x6f\x6f\x6b\x69\x65\x2c\x20\x6d\x69\x73\x73\x69\x6e\x67\x20\x64\x69\x73\x70\x6c\x61\x79\x2e"
);return ((0x0686+ 1866-0x0dcf));}if (((not (defined ($protoname)))or (
$protoname eq ("")))){Logger::warning (
"\x43\x61\x6e\x6e\x6f\x74\x20\x61\x64\x64\x20\x63\x6f\x6f\x6b\x69\x65\x2c\x20\x6d\x69\x73\x73\x69\x6e\x67\x20\x70\x72\x6f\x74\x6f\x6e\x61\x6d\x65\x2e"
);return ((0x0ff1+ 950-0x13a6));}if (((not (defined ($hexkey)))or ($hexkey eq 
("")))){Logger::warning (((
"\x43\x61\x6e\x6e\x6f\x74\x20\x61\x64\x64\x20\x63\x6f\x6f\x6b\x69\x65\x20\x66\x6f\x72\x20\x64\x69\x73\x70\x6c\x61\x79\x20"
.$dpyname).
"\x2c\x20\x6d\x69\x73\x73\x69\x6e\x67\x20\x68\x65\x78\x6b\x65\x79\x2e"));return 
((0x196c+ 121-0x19e4));}if (($hexkey eq "\x65\x6d\x70\x74\x79")){Logger::debug (
"\x53\x6b\x69\x70\x20\x61\x64\x64\x69\x6e\x67\x20\x65\x6d\x70\x74\x79\x20\x63\x6f\x6f\x6b\x69\x65\x2e"
);return ((0x01d8+ 1204-0x068c));}(my $returnValue=libnxh::NXAddCookie (
$inputfilename,$dpyname,$protoname,$hexkey));if (($returnValue!=
(0x18a1+  68-0x18e5))){(my $errorInt=libnxh::NXGetError ());(my $error=
libnxh::NXGetErrorName ());(my $errorString=libnxh::NXGetErrorString ());(my $path
=Common::NXFile::dirname ($inputfilename));(my $filename=
Common::NXFile::basename ($inputfilename));if (($error eq 
"\x45\x41\x43\x43\x45\x53")){(my $errorMessage=((((
"\x43\x61\x6e\x6e\x6f\x74\x20\x77\x72\x69\x74\x65\x20\x74\x6f\x20".$filename).
"\x20\x66\x69\x6c\x65\x20\x69\x6e\x20").$path).
"\x20\x6f\x6e\x20\x74\x68\x65\x20\x6c\x6f\x63\x61\x6c\x20\x68\x6f\x73\x74\x2e\x20\x50\x6c\x65\x61\x73\x65\x20\x76\x65\x72\x69\x66\x79\x20\x70\x65\x72\x6d\x69\x73\x73\x69\x6f\x6e\x20\x61\x74\x74\x72\x69\x62\x75\x74\x65\x73\x20\x66\x6f\x72\x20\x74\x68\x61\x74\x20\x66\x69\x6c\x65"
));main::nxwrite (main::nxgetSTDERR (),((
"\x4e\x58\x3e\x20\x35\x39\x38\x20\x45\x72\x72\x6f\x72\x3a\x20".$errorMessage).
"\x2e\x0a"));Logger::error ($errorMessage);main::clean_and_die (
"\x65\x43\x61\x6e\x6e\x6f\x74\x57\x72\x69\x74\x65\x54\x6f\x46\x69\x6c\x65\x4f\x6e\x54\x68\x65\x4c\x6f\x63\x61\x6c\x48\x6f\x73\x74\x56\x65\x72\x69\x66\x79\x50\x65\x72\x6d\x69\x73\x73\x69\x6f\x6e"
,$filename,$path);}else{(my $errorMessage=(((((
"\x43\x61\x6e\x6e\x6f\x74\x20\x77\x72\x69\x74\x65\x20\x74\x6f\x20".$filename).
"\x20\x66\x69\x6c\x65\x20\x69\x6e\x20").$path).
"\x20\x6f\x6e\x20\x74\x68\x65\x20\x6c\x6f\x63\x61\x6c\x20\x68\x6f\x73\x74\x2e\x20"
).$errorString));main::nxwrite (main::nxgetSTDERR (),((
"\x4e\x58\x3e\x20\x35\x39\x38\x20\x45\x72\x72\x6f\x72\x3a\x20".$errorMessage).
"\x0a"));Logger::error ($errorMessage);main::clean_and_die (
"\x65\x43\x61\x6e\x6e\x6f\x74\x57\x72\x69\x74\x65\x54\x6f\x46\x69\x6c\x65\x4f\x6e\x54\x68\x65\x4c\x6f\x63\x61\x6c\x48\x6f\x73\x74"
,$filename,$path,$errorString);}}return ($returnValue);}sub removeCookie{(my $inputfilename
=shift (@_));(my $dpyname=shift (@_));if (((not (defined ($inputfilename)))or (
$inputfilename eq ("")))){Logger::warning (
"\x43\x61\x6e\x6e\x6f\x74\x20\x72\x65\x6d\x6f\x76\x65\x20\x63\x6f\x6f\x6b\x69\x65\x2c\x20\x6d\x69\x73\x73\x69\x6e\x67\x20\x69\x6e\x70\x75\x74\x20\x66\x69\x6c\x65\x20\x6e\x61\x6d\x65\x2e"
);return ((0x01c7+ 1545-0x07cf));}if (((not (defined ($dpyname)))or ($dpyname eq
 ("")))){Logger::warning (
"\x43\x61\x6e\x6e\x6f\x74\x20\x72\x65\x6d\x6f\x76\x65\x20\x63\x6f\x6f\x6b\x69\x65\x2c\x20\x6d\x69\x73\x73\x69\x6e\x67\x20\x64\x69\x73\x70\x6c\x61\x79\x2e"
);return ((0x03b0+ 7163-0x1faa));}return ((!libnxh::NXRemoveCookie (
$inputfilename,$dpyname)));}sub listCookie{(my $inputfilename=shift (@_));(my $nDisplay
=shift (@_));(my $ref_dpyNames=shift (@_));if (((not (defined ($inputfilename)))
or ($inputfilename eq ("")))){Logger::warning (
"\x43\x61\x6e\x6e\x6f\x74\x20\x6c\x69\x73\x74\x20\x63\x6f\x6f\x6b\x69\x65\x2c\x20\x6d\x69\x73\x73\x69\x6e\x67\x20\x69\x6e\x70\x75\x74\x20\x66\x69\x6c\x65\x20\x6e\x61\x6d\x65\x2e"
);return ((0x1d56+ 1028-0x2159));}if (((not (defined ($nDisplay)))or ($nDisplay 
eq ("")))){Logger::warning (
"\x43\x61\x6e\x6e\x6f\x74\x20\x6c\x69\x73\x74\x20\x63\x6f\x6f\x6b\x69\x65\x2c\x20\x6d\x69\x73\x73\x69\x6e\x67\x20\x64\x69\x73\x70\x6c\x61\x79\x2e"
);return ((0x142c+ 1784-0x1b23));}if ((not (defined ($ref_dpyNames)))){
Logger::warning (
"\x43\x61\x6e\x6e\x6f\x74\x20\x6c\x69\x73\x74\x20\x63\x6f\x6f\x6b\x69\x65\x2c\x20\x6d\x69\x73\x73\x69\x6e\x67\x20\x72\x65\x74\x75\x72\x6e\x20\x76\x61\x72\x69\x61\x62\x6c\x65\x2e"
);return ((0x000f+ 6772-0x1a82));}return ((!libnxh::NXListCookie ($inputfilename
,$nDisplay,$ref_dpyNames)));}"\x3f\x3f\x3f";

==> nomachine-8.14.2-1-x86_64.pkg.tar.zst: NX/lib/perl/nxnode/NXAuth.pm <==
############################################################################
#                                                                          #
#  Copyright (c) 2001, 2024 NoMachine, http://www.nomachine.com.           #
#                                                                          #
#  NXNODE, NX protocol compression and NX extensions to this software      #
#  are copyright of NoMachine. Redistribution and use of the present       #
#  software is allowed according to terms specified in the file LICENSE    #
#  which comes in the source distribution.                                 #
#                                                                          #
#  Check http://www.nomachine.com/licensing.html for applicability.        #
#                                                                          #
#  NX and NoMachine are trademarks of NoMachine S.a.r.l.                   #
#                                                                          #
#  All rights reserved.                                                    #
#                                                                          #
############################################################################
sub NXAuth::BEGIN{package NXAuth;no warnings;require strict;do{
"\x73\x74\x72\x69\x63\x74"->unimport ("\x72\x65\x66\x73")};}sub NXAuth::BEGIN{
package NXAuth;no warnings;require strict;do{"\x73\x74\x72\x69\x63\x74"->
unimport ("\x73\x75\x62\x73")};}sub NXAuth::BEGIN{package NXAuth;no warnings;
require Exporter;do{"\x45\x78\x70\x6f\x72\x74\x65\x72"->import};}sub 
NXAuth::BEGIN{package NXAuth;no warnings;require Common::NXBegin;do{
"\x43\x6f\x6d\x6d\x6f\x6e\x3a\x3a\x4e\x58\x42\x65\x67\x69\x6e"->import};}package
 NXAuth;no warnings;require Common::NXFile;(our (@ISA)=
"\x45\x78\x70\x6f\x72\x74\x65\x72");(our (@EXPORT)=(
"\x6e\x78\x61\x75\x74\x68\x41\x64\x64\x43\x6f\x6f\x6b\x69\x65",
"\x6e\x78\x61\x75\x74\x68\x52\x65\x6d\x6f\x76\x65\x43\x6f\x6f\x6b\x69\x65",
"\x6e\x78\x61\x75\x74\x68\x4c\x69\x73\x74\x43\x6f\x6f\x6b\x69\x65",
"\x6e\x78\x61\x75\x74\x68\x4c\x6f\x67\x43\x6f\x6f\x6b\x69\x65\x46\x72\x6f\x6d\x46\x69\x6c\x65"
));sub nxauthAddCookie{return (addCookie (@_));}sub nxauthLogCookieFromFile{(my $file
=shift (@_));my ($entries);(my (@command)=(
"\x2f\x75\x73\x72\x2f\x62\x69\x6e\x2f\x78\x61\x75\x74\x68","\x2d\x66",$file,
"\x6c\x69\x73\x74"));(my ($cmd_err,$cmd_out,$exit_value)=main::run_command ((
\@command),("")));}sub nxauthRemoveCookie{return (removeCookie (@_));}sub 
removeFromScript{(my $xauthorityFile=shift (@_));(my $script=shift (@_));if (((
not (defined ($xauthorityFile)))or ($xauthorityFile eq ("")))){Logger::warning (
"\x4d\x69\x73\x73\x69\x6e\x67\x20\x58\x61\x75\x74\x68\x6f\x72\x69\x74\x79\x20\x66\x69\x6c\x65"
);return ((0x08a1+ 7457-0x25c1));}Logger::debug ((
"\x47\x6f\x69\x6e\x67\x20\x74\x6f\x20\x6f\x70\x65\x6e\x20\x73\x63\x72\x69\x70\x74\x3a\x20"
.$script));(my $scriptFD=main::nxopen ($script,$NXBits::O_RDONLY,
(0x0f5d+ 3448-0x1cd5)));if ((not (defined ($scriptFD)))){(my $errorNumber=
libnxh::NXGetError ());(my $errorstring=libnxh::NXGetErrorString ());
Logger::warning (((
"\x43\x61\x6e\x6e\x6f\x74\x20\x6f\x70\x65\x6e\x20\x73\x63\x72\x69\x70\x74\x3a\x20"
.$script)."\x2e"));Logger::warning (((((
"\x45\x72\x72\x6f\x72\x20\x69\x73\x3a\x20".$errorNumber)."\x2c\x20").
$errorstring)."\x2e"));return ((0x1333+ 1617-0x1983));}while (main::nxreadLine (
$scriptFD,(\$_))){if ( /remove\s(\S*:\d{1,5})$/ ){(my $dpyname=$1);if ((not (
removeCookie ($xauthorityFile,$dpyname)))){(my $errorNumber=libnxh::NXGetError 
());(my $errorstring=libnxh::NXGetErrorString ());Logger::warning (((((
"\x43\x61\x6e\x6e\x6f\x74\x20\x72\x65\x6d\x6f\x76\x65\x20\x63\x6f\x6f\x6b\x69\x65\x20\x66\x6f\x72\x20"
.$dpyname)."\x20\x66\x72\x6f\x6d\x20").$xauthorityFile)."\x2e"));Logger::warning
 ((((("\x45\x72\x72\x6f\x72\x20\x69\x73\x3a\x20".$errorNumber)."\x2c\x20").
$errorstring)."\x2e"));}}}main::nxclose ($scriptFD);return (
(0x01da+ 2137-0x0a33));}sub nxauthListCookie{return (listCookie (@_));}sub 
addCookie{(my $inputfilename=shift (@_));(my $dpyname=shift (@_));(my $protoname
=shift (@_));(my $hexkey=shift (@_));if (((not (defined ($inputfilename)))or (
$inputfilename eq ("")))){Logger::warning (
"\x43\x61\x6e\x6e\x6f\x74\x20\x61\x64\x64\x20\x63\x6f\x6f\x6b\x69\x65\x2c\x20\x6d\x69\x73\x73\x69\x6e\x67\x20\x69\x6e\x70\x75\x74\x20\x66\x69\x6c\x65\x20\x6e\x61\x6d\x65\x2e"
);return ((0x08da+ 6444-0x2205));}if (((not (defined ($dpyname)))or ($dpyname eq
 ("")))){Logger::warning (
"\x43\x61\x6e\x6e\x6f\x74\x20\x61\x64\x64\x20\x63\x6f\x6f\x6b\x69\x65\x2c\x20\x6d\x69\x73\x73\x69\x6e\x67\x20\x64\x69\x73\x70\x6c\x61\x79\x2e"
);return ((0x10aa+ 2443-0x1a34));}if (((not (defined ($protoname)))or (
$protoname eq ("")))){Logger::warning (
"\x43\x61\x6e\x6e\x6f\x74\x20\x61\x64\x64\x20\x63\x6f\x6f\x6b\x69\x65\x2c\x20\x6d\x69\x73\x73\x69\x6e\x67\x20\x70\x72\x6f\x74\x6f\x6e\x61\x6d\x65\x2e"
);return ((0x0c2f+ 5370-0x2128));}if (((not (defined ($hexkey)))or ($hexkey eq 
("")))){Logger::warning (((
"\x43\x61\x6e\x6e\x6f\x74\x20\x61\x64\x64\x20\x63\x6f\x6f\x6b\x69\x65\x20\x66\x6f\x72\x20\x64\x69\x73\x70\x6c\x61\x79\x20"
.$dpyname).
"\x2c\x20\x6d\x69\x73\x73\x69\x6e\x67\x20\x68\x65\x78\x6b\x65\x79\x2e"));return 
((0x1717+ 1319-0x1c3d));}if (($hexkey eq "\x65\x6d\x70\x74\x79")){Logger::debug 
(
"\x53\x6b\x69\x70\x20\x61\x64\x64\x69\x6e\x67\x20\x65\x6d\x70\x74\x79\x20\x63\x6f\x6f\x6b\x69\x65\x2e"
);return ((0x1304+ 4479-0x2483));}(my $returnValue=libnxh::NXAddCookie (
$inputfilename,$dpyname,$protoname,$hexkey));if (($returnValue!=
(0x1283+ 5189-0x26c8))){(my $errorInt=libnxh::NXGetError ());(my $error=
libnxh::NXGetErrorName ());(my $errorString=libnxh::NXGetErrorString ());(my $path
=Common::NXFile::dirname ($inputfilename));(my $filename=
Common::NXFile::basename ($inputfilename));if (($error eq 
"\x45\x41\x43\x43\x45\x53")){(my $errorMessage=((((
"\x43\x61\x6e\x6e\x6f\x74\x20\x77\x72\x69\x74\x65\x20\x74\x6f\x20".$filename).
"\x20\x66\x69\x6c\x65\x20\x69\x6e\x20").$path).
"\x20\x6f\x6e\x20\x74\x68\x65\x20\x6c\x6f\x63\x61\x6c\x20\x68\x6f\x73\x74\x2e\x20\x50\x6c\x65\x61\x73\x65\x20\x76\x65\x72\x69\x66\x79\x20\x70\x65\x72\x6d\x69\x73\x73\x69\x6f\x6e\x20\x61\x74\x74\x72\x69\x62\x75\x74\x65\x73\x20\x66\x6f\x72\x20\x74\x68\x61\x74\x20\x66\x69\x6c\x65"
));main::nxwrite (main::nxgetSTDERR (),((
"\x4e\x58\x3e\x20\x35\x39\x38\x20\x45\x72\x72\x6f\x72\x3a\x20".$errorMessage).
"\x2e\x0a"));Logger::error ($errorMessage);main::clean_and_die (
"\x65\x43\x61\x6e\x6e\x6f\x74\x57\x72\x69\x74\x65\x54\x6f\x46\x69\x6c\x65\x4f\x6e\x54\x68\x65\x4c\x6f\x63\x61\x6c\x48\x6f\x73\x74\x56\x65\x72\x69\x66\x79\x50\x65\x72\x6d\x69\x73\x73\x69\x6f\x6e"
,$filename,$path);}else{(my $errorMessage=(((((
"\x43\x61\x6e\x6e\x6f\x74\x20\x77\x72\x69\x74\x65\x20\x74\x6f\x20".$filename).
"\x20\x66\x69\x6c\x65\x20\x69\x6e\x20").$path).
"\x20\x6f\x6e\x20\x74\x68\x65\x20\x6c\x6f\x63\x61\x6c\x20\x68\x6f\x73\x74\x2e\x20"
).$errorString));main::nxwrite (main::nxgetSTDERR (),((
"\x4e\x58\x3e\x20\x35\x39\x38\x20\x45\x72\x72\x6f\x72\x3a\x20".$errorMessage).
"\x0a"));Logger::error ($errorMessage);main::clean_and_die (
"\x65\x43\x61\x6e\x6e\x6f\x74\x57\x72\x69\x74\x65\x54\x6f\x46\x69\x6c\x65\x4f\x6e\x54\x68\x65\x4c\x6f\x63\x61\x6c\x48\x6f\x73\x74"
,$filename,$path,$errorString);}}return ($returnValue);}sub removeCookie{(my $inputfilename
=shift (@_));(my $dpyname=shift (@_));if (((not (defined ($inputfilename)))or (
$inputfilename eq ("")))){Logger::warning (
"\x43\x61\x6e\x6e\x6f\x74\x20\x72\x65\x6d\x6f\x76\x65\x20\x63\x6f\x6f\x6b\x69\x65\x2c\x20\x6d\x69\x73\x73\x69\x6e\x67\x20\x69\x6e\x70\x75\x74\x20\x66\x69\x6c\x65\x20\x6e\x61\x6d\x65\x2e"
);return ((0x08ef+ 1190-0x0d94));}if (((not (defined ($dpyname)))or ($dpyname eq
 ("")))){Logger::warning (
"\x43\x61\x6e\x6e\x6f\x74\x20\x72\x65\x6d\x6f\x76\x65\x20\x63\x6f\x6f\x6b\x69\x65\x2c\x20\x6d\x69\x73\x73\x69\x6e\x67\x20\x64\x69\x73\x70\x6c\x61\x79\x2e"
);return ((0x0009+ 5655-0x161f));}return ((!libnxh::NXRemoveCookie (
$inputfilename,$dpyname)));}sub listCookie{(my $inputfilename=shift (@_));(my $nDisplay
=shift (@_));(my $ref_dpyNames=shift (@_));if (((not (defined ($inputfilename)))
or ($inputfilename eq ("")))){Logger::warning (
"\x43\x61\x6e\x6e\x6f\x74\x20\x6c\x69\x73\x74\x20\x63\x6f\x6f\x6b\x69\x65\x2c\x20\x6d\x69\x73\x73\x69\x6e\x67\x20\x69\x6e\x70\x75\x74\x20\x66\x69\x6c\x65\x20\x6e\x61\x6d\x65\x2e"
);return ((0x04a6+ 2387-0x0df8));}if (((not (defined ($nDisplay)))or ($nDisplay 
eq ("")))){Logger::warning (
"\x43\x61\x6e\x6e\x6f\x74\x20\x6c\x69\x73\x74\x20\x63\x6f\x6f\x6b\x69\x65\x2c\x20\x6d\x69\x73\x73\x69\x6e\x67\x20\x64\x69\x73\x70\x6c\x61\x79\x2e"
);return ((0x18ec+ 2160-0x215b));}if ((not (defined ($ref_dpyNames)))){
Logger::warning (
"\x43\x61\x6e\x6e\x6f\x74\x20\x6c\x69\x73\x74\x20\x63\x6f\x6f\x6b\x69\x65\x2c\x20\x6d\x69\x73\x73\x69\x6e\x67\x20\x72\x65\x74\x75\x72\x6e\x20\x76\x61\x72\x69\x61\x62\x6c\x65\x2e"
);return ((0x0e3a+ 4171-0x1e84));}return ((!libnxh::NXListCookie ($inputfilename
,$nDisplay,$ref_dpyNames)));}"\x3f\x3f\x3f";
